@@ -15,7 +15,7 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 package Linux::LXC;
-$Linux::LXC::VERSION = '1.00_00';
+$Linux::LXC::VERSION = '1.0002';
 
 use v5.0;
 
@@ -153,10 +153,24 @@ sub put {
 		croak 'Destination should be an absolute path';
 	}
 	$dest = $this->get_lxc_path().'/rootfs'.$dest;
-	$dest =~ /^(.*\/)/;
-	-d $1 or `mkdir -p $1`;
-	`cp -R $input $dest`;
-	`chown -R $uid:$uid $dest` if defined $uid;
+	my ($dir_dest) = $dest =~ /^(.*\/)/;
+	if (defined $uid) {
+		my @folders = split(/\//, $dir_dest);
+		shift @folders;
+		my $abs_folder = '';
+		while (my $cur_folder = shift @folders) {
+			$abs_folder .= '/' . $cur_folder;
+			if (!-d $abs_folder) {
+				`mkdir $abs_folder`;
+				`chown $uid:$uid $abs_folder`;
+			}
+		}
+		`cp -R $input $dest`;
+		`chown -R $uid:$uid $dest` if defined $uid;
+	} else {
+		-d $dir_dest or `mkdir -p $dir_dest`;
+		`cp -R $input $dest`;
+	}
 }
 
 sub del_config {
